function PlotDendrogram(Dists, LinkMet)
%
% PlotDendrogram(Dists, LinkMet)
%
% Plots the dendrogram, obtained by a hierarchical clustering method
%
%
% INPUT:
% - Dists   : Distance matrix.
% - LinkMet : Hierarchical clustering method:
%             'single', 'average' or 'complete'
%
%
%
%  Author:   Analytical Chemistry
%            Institute for Molecules and Materials
%            Radboud University Nijmegen
%            Nijmegen, The Netherlands
%  Created:  November 24, 2006
%  Updated:  
%

% Adapted from:
% R.P.W. Duin, Email: duin@ph.tn.tudelft.nl
% Faculty of Applied Physics
% Delft University of Technology, The Netherlands
% and from:
% T.N Thanh, Email: tnthanh@sci.kun.nl
% Laboratory of Analytical Chemistry
% University of Nijmegen (KUN), The Netherlands

[m,m1] = size(Dists);
k = m;
Dists = Dists + diag(inf*ones(1,m));  % Set diagonal at infinity.
V = linspace(1,m+2,m+2);  % Positions of objects in final linear object set
F = inf * ones(1,m+1);    % Distance of next cluster to previous cluster to
                          % be stored at first point of second cluster
Z = ones(1,m);
for n = 1:m-1
    % Find minimum distance Dists(i,j) i<j
	[di,I] = min(Dists); [dj,j] = min(di); i = I(j);
    
    % Make sure only one part of the distance matrix is considered
	if i > j, j1 = j; j = i; i = j1; end
    
	% Combine clusters i,j
    switch LinkMet
        case 'single'
            Dists(i,:) = min(Dists(i,:),Dists(j,:));
        case 'complete'
            Dists(i,:) = max(Dists(i,:),Dists(j,:));
        case 'average'
            Dists(i,:) = (Z(i)*Dists(i,:) + Z(j)*Dists(j,:))/(Z(i)+Z(j));
            Z(i:j-1) = [Z(i)+Z(j),Z(i+1:j-1)]; Z(j) = [];
    end

	Dists(:,i) = Dists(i,:)';
	Dists(i,i) = inf;
	Dists(j,:) = []; Dists(:,j) = [];
    % Store cluster distance
	F(V(j)) = dj;
    % Move second cluster in linear ordering right after first cluster
	IV = [1:V(i+1)-1,V(j):V(j+1)-1,V(i+1):V(j)-1,V(j+1):m+1];
    F = F(IV);   % Keep track of object positions and cluster distances
	V = [V(1:i),V(i+1:j) + V(j+1) - V(j),V(j+2:m-n+3)];
end

S = sort(-F); t = -S(k+1);  % Find cluster level
I = [find(F >= t),m+1];     % Find all indices where cluster starts
DenGram = [I(2:k+1) - I(1:k); F(I(1:k))];

%%%%%%%%%%
[n,m] = size(DenGram);
[S,I] = sort(DenGram(2,:));
C = [0:m-1;1:m;zeros(1,m);2:m+1];
X = zeros(m,4); Y = X;

for i=1:m-1
	X(i,:) = [C(2,I(i)), C(2,I(i)), C(2,C(1,I(i))), C(2,C(1,I(i)))];
	Y(i,:) = [C(3,I(i)), S(i), S(i), C(3,C(1,I(i)))];
	C(:,C(1,I(i))) = [C(1,C(1,I(i))), (C(2,I(i)) + C(2,C(1,I(i))))/2, ...
        S(i), C(4,I(i))]';
	C(1,C(4,I(i))) = C(1,I(i));
end
X(m,:) = [0 0 m+1 m+1];
Y(m,:) = [0 0 0 0];

figure;
plot(X', Y', '-b');
title([LinkMet ' linkage']);
h = gca; set(h,'box','off');

return
